Parameters
==========================

.. autoclass:: entmoot.models.model_params.UncParams
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: entmoot.models.model_params.TrainParams
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: entmoot.models.model_params.TreeTrainParams
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: entmoot.models.model_params.EntingParams
   :members:
   :undoc-members:
   :show-inheritance:
